@@ -1,6 +1,6 @@
 #  You may distribute under the terms of the GNU General Public License
 #
-#  (C) Paul Evans, 2011 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2013 -- leonerd@leonerd.org.uk
 
 package Circle::FE::Term::Widget::Label;
 
@@ -16,7 +16,11 @@ sub build
    my $class = shift;
    my ( $obj, $tab ) = @_;
 
-   my $widget = Tickit::Widget::Static->new( text => "" );
+   my $widget = Tickit::Widget::Static->new(
+      classes => $obj->prop( "classes" ),
+      text => "",
+   );
+
    $obj->watch_property(
       property => "text",
       on_set   => sub { $widget->set_text( $_[0] ) },
@@ -26,4 +30,11 @@ sub build
    return $widget;
 }
 
+Tickit::Style->load_style( <<'EOF' );
+Static.ident {
+  bg: "blue";
+}
+
+EOF
+
 0x55AA;
